@@ -5,25 +5,25 @@
         <location filename="mainwindow.ui" line="26"/>
         <location filename="ui_mainwindow.h" line="756"/>
         <source>Network Assistant</source>
-        <translation type="unfinished"/>
+        <translation>מסייע הרשת</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="70"/>
         <location filename="ui_mainwindow.h" line="770"/>
         <source>Status</source>
-        <translation type="unfinished"/>
+        <translation>מצב</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="76"/>
         <location filename="ui_mainwindow.h" line="757"/>
         <source>IP address</source>
-        <translation type="unfinished"/>
+        <translation>כתובת IP</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="112"/>
         <location filename="ui_mainwindow.h" line="760"/>
         <source>Hardware detected</source>
-        <translation type="unfinished"/>
+        <translation>זוהתה חומרה</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="143"/>
@@ -33,121 +33,121 @@
         <location filename="ui_mainwindow.h" line="774"/>
         <location filename="ui_mainwindow.h" line="780"/>
         <source>Re-scan</source>
-        <translation type="unfinished"/>
+        <translation>סריקה מחדש</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="215"/>
         <location filename="ui_mainwindow.h" line="762"/>
         <source>Active interface</source>
-        <translation type="unfinished"/>
+        <translation>מנשק פעיל</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="231"/>
         <location filename="ui_mainwindow.h" line="764"/>
         <source>WiFi status</source>
-        <translation type="unfinished"/>
+        <translation>מצב רשת אלחוטית</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="253"/>
         <location filename="ui_mainwindow.h" line="767"/>
         <source>Unblocks all soft/hard blocked wireless devices</source>
-        <translation type="unfinished"/>
+        <translation>משחררת את החסימות הרכות/קשות של ההתקנים האלחוטיים</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="256"/>
         <location filename="ui_mainwindow.h" line="769"/>
         <source>Unblock WiFi Devices</source>
-        <translation type="unfinished"/>
+        <translation>שחרור התקני רשת אלחוטית</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="288"/>
         <location filename="ui_mainwindow.h" line="776"/>
         <source>Linux drivers</source>
-        <translation type="unfinished"/>
+        <translation>מנהלי התקנים של לינוקס</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="300"/>
         <location filename="ui_mainwindow.h" line="771"/>
         <source>Associated Linux drivers</source>
-        <translation type="unfinished"/>
+        <translation>מנהלי התקנים משויכים של לינוקס</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="309"/>
         <location filename="ui_mainwindow.h" line="772"/>
         <source>Load Driver</source>
-        <translation type="unfinished"/>
+        <translation>טעינת מנהל התקן</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="372"/>
         <location filename="ui_mainwindow.h" line="773"/>
         <source>Unload Driver</source>
-        <translation type="unfinished"/>
+        <translation>פריקת מנהל התקן</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="409"/>
         <location filename="ui_mainwindow.h" line="775"/>
         <source>Block Driver</source>
-        <translation type="unfinished"/>
+        <translation>חסימת מנהל התקן</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="428"/>
         <location filename="ui_mainwindow.h" line="785"/>
         <source>Windows drivers</source>
-        <translation type="unfinished"/>
+        <translation>מנהלי התקנים ל־Windows</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="434"/>
         <location filename="ui_mainwindow.h" line="777"/>
         <source>Available Windows drivers</source>
-        <translation type="unfinished"/>
+        <translation>מנהלי התקנים זמינים ל־Windows</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="468"/>
         <location filename="ui_mainwindow.h" line="778"/>
         <source>Remove Driver</source>
-        <translation type="unfinished"/>
+        <translation>הסרת מנהל התקן</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="479"/>
         <location filename="ui_mainwindow.h" line="779"/>
         <source>Add Driver</source>
-        <translation type="unfinished"/>
+        <translation>הוספת מנהל התקן</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="520"/>
         <location filename="ui_mainwindow.h" line="781"/>
         <source>About NDISwrapper</source>
-        <translation type="unfinished"/>
+        <translation>על NDISwrapper</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="532"/>
         <location filename="ui_mainwindow.h" line="782"/>
         <source>Install NDISwrapper</source>
-        <translation type="unfinished"/>
+        <translation>התקנת NDISwrapper</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="543"/>
         <location filename="ui_mainwindow.h" line="783"/>
         <source>In order to use Windows drivers you need first to install NDISwrapper</source>
-        <translation type="unfinished"/>
+        <translation>כדי להשתמש במנהלי התקנים שיועדו ל־Windows עליך להתקין את NDISwrapper תחילה</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="559"/>
         <location filename="ui_mainwindow.h" line="784"/>
         <source>Uninstall NDISwrapper</source>
-        <translation type="unfinished"/>
+        <translation>הסרת NDISwrapper</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="591"/>
         <location filename="ui_mainwindow.h" line="798"/>
         <source>Net diagnostics</source>
-        <translation type="unfinished"/>
+        <translation>ניתוח הרשת</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="603"/>
         <location filename="ui_mainwindow.h" line="786"/>
         <source>Ping</source>
-        <translation type="unfinished"/>
+        <translation>פינג</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="609"/>
@@ -155,13 +155,13 @@
         <location filename="ui_mainwindow.h" line="787"/>
         <location filename="ui_mainwindow.h" line="793"/>
         <source>Target URL:</source>
-        <translation type="unfinished"/>
+        <translation>כתובת יעד:</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="619"/>
         <location filename="ui_mainwindow.h" line="788"/>
         <source>Packets</source>
-        <translation type="unfinished"/>
+        <translation>מנות נתונים</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="661"/>
@@ -169,7 +169,7 @@
         <location filename="ui_mainwindow.h" line="789"/>
         <location filename="ui_mainwindow.h" line="795"/>
         <source>Start</source>
-        <translation type="unfinished"/>
+        <translation>התחלה</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="678"/>
@@ -177,7 +177,7 @@
         <location filename="ui_mainwindow.h" line="790"/>
         <location filename="ui_mainwindow.h" line="796"/>
         <source>Clear</source>
-        <translation type="unfinished"/>
+        <translation>מחיקה</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="692"/>
@@ -191,19 +191,19 @@
         <location filename="mainwindow.ui" line="720"/>
         <location filename="ui_mainwindow.h" line="792"/>
         <source>Traceroute</source>
-        <translation type="unfinished"/>
+        <translation>מעקב נתיב</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="736"/>
         <location filename="ui_mainwindow.h" line="794"/>
         <source>Hops</source>
-        <translation type="unfinished"/>
+        <translation>נק׳ אמצע</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="868"/>
         <location filename="ui_mainwindow.h" line="799"/>
         <source>About...</source>
-        <translation>אודות...</translation>
+        <translation>על אודות…</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="891"/>
@@ -215,169 +215,169 @@
         <location filename="mainwindow.ui" line="959"/>
         <location filename="ui_mainwindow.h" line="805"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"/>
+        <translation>&amp;סגירה</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="966"/>
         <location filename="ui_mainwindow.h" line="807"/>
         <source>Alt+C</source>
-        <translation type="unfinished"/>
+        <translation>Alt+C</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="87"/>
         <source>IP address from router:</source>
-        <translation type="unfinished"/>
+        <translation>כתובת ה־IP מהנתב:</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="88"/>
         <source>External IP address:</source>
-        <translation type="unfinished"/>
+        <translation>כתובת IP חיצונית:</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="196"/>
         <location filename="mainwindow.cpp" line="210"/>
         <location filename="mainwindow.cpp" line="224"/>
         <source>&amp;Copy</source>
-        <translation type="unfinished"/>
+        <translation>ה&amp;עתקה</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="198"/>
         <location filename="mainwindow.cpp" line="212"/>
         <location filename="mainwindow.cpp" line="226"/>
         <source>Ctrl+C</source>
-        <translation type="unfinished"/>
+        <translation>Ctrl+C</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="199"/>
         <location filename="mainwindow.cpp" line="213"/>
         <location filename="mainwindow.cpp" line="227"/>
         <source>Copy &amp;All</source>
-        <translation type="unfinished"/>
+        <translation>העתקה של ה&amp;כול</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="201"/>
         <location filename="mainwindow.cpp" line="215"/>
         <location filename="mainwindow.cpp" line="229"/>
         <source>Ctrl+A</source>
-        <translation type="unfinished"/>
+        <translation>Ctrl+A</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="261"/>
         <location filename="mainwindow.cpp" line="278"/>
         <source>Traceroute not installed</source>
-        <translation type="unfinished"/>
+        <translation>Traceroute (מעקב נתיב) לא מותקן</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="262"/>
         <source>Traceroute is not installed, do you want to install it now?</source>
-        <translation type="unfinished"/>
+        <translation>Traceroute (מעקב נתיב) לא מותקן, להתקין אותו כעת?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="269"/>
         <source>Traceroute hasn&apos;t been installed</source>
-        <translation type="unfinished"/>
+        <translation>Traceroute (מעקב נתיב) לא הותקן</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="270"/>
         <source>Traceroute cannot be installed. This may mean you are using the LiveCD or you are unable to reach the software repository,</source>
-        <translation type="unfinished"/>
+        <translation>לא ניתן להתקין את Traceroute (מעקב נתיב). יתכן שזה קורה כיוון שזאת הפעלה מתקליטור חי או שאין לך גישה למאגרי התכנה.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="279"/>
         <source>Traceroute is not installed and no Internet connection could be detected so it cannot be installed</source>
-        <translation type="unfinished"/>
+        <translation>Traceroute (מעקב נתיב) אינו מותקן ולא זוהה חיבור לאינטרנט ולכן גם לא ניתן להתקין אותו</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="285"/>
         <location filename="mainwindow.cpp" line="326"/>
         <source>No destination host</source>
-        <translation type="unfinished"/>
+        <translation>אין מארח יעד</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="286"/>
         <location filename="mainwindow.cpp" line="327"/>
         <source>Please fill in the destination host field</source>
-        <translation type="unfinished"/>
+        <translation>נא למלא את שדה מארח היעד</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="440"/>
         <source>Loaded Drivers</source>
-        <translation type="unfinished"/>
+        <translation>מנהלי התקנים שנטענו</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="449"/>
         <source>Unloaded Drivers</source>
-        <translation type="unfinished"/>
+        <translation>מנהלי התקנים שלא נטענו</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="464"/>
         <source>Blocked Drivers</source>
-        <translation type="unfinished"/>
+        <translation>מנהלי התקנים חסומים</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="486"/>
         <source>Blocked Broadcom Drivers</source>
-        <translation type="unfinished"/>
+        <translation>מנהלי התקנים חסומים של Broadcom</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="894"/>
         <source>enabled</source>
-        <translation type="unfinished"/>
+        <translation>מופעל</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="897"/>
         <source>disabled</source>
-        <translation type="unfinished"/>
+        <translation>מושבת</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="900"/>
         <source>WiFi hardware switch is off</source>
-        <translation type="unfinished"/>
+        <translation>בורר החומרה של הרשת האלחוטית כבוי</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="908"/>
         <source>Locate the Windows driver you want to add</source>
-        <translation type="unfinished"/>
+        <translation>נא לאתר את מנהל ההתקן של Windows שברצונך להוסיף</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="908"/>
         <source>Windows installation information file (*.inf)</source>
-        <translation type="unfinished"/>
+        <translation>קובץ פרטי התקנה של Windows‏ (‎*.inf)</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="939"/>
         <source>*.sys file not found</source>
-        <translation type="unfinished"/>
+        <translation>לא נמצא קובץ ‎*.sys</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="939"/>
         <source>The *.sys files must be in the same location as the *.inf file. %1 cannot be found</source>
-        <translation type="unfinished"/>
+        <translation>קובצי ה־‎*.sys חייבים להיות באותו המקום יחד עם קובץ ה־‎*.inf. לא ניתן למצוא את %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="948"/>
         <source>sys file reference not found</source>
-        <translation type="unfinished"/>
+        <translation>ההפניה לקובץ ה־sys לא נמצאה</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="948"/>
         <source>The sys file for the given driver cannot be determined after parsing the inf file</source>
-        <translation type="unfinished"/>
+        <translation>לא ניתן להגדיר מה הוא קובץ ה־sys עבור מנהל ההתקן הנתון לאחר פענוח קובץ ה־inf</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="967"/>
         <source>Ndiswrapper driver removed.</source>
-        <translation type="unfinished"/>
+        <translation>מנהל ההתקן עם Ndiswrapper הוסר.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="975"/>
         <source>%1 Help</source>
-        <translation type="unfinished"/>
+        <translation>עזרה עבור %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="1012"/>
         <source>About %1</source>
-        <translation type="unfinished"/>
+        <translation>על אודות %1</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="1013"/>
@@ -387,17 +387,17 @@
     <message>
         <location filename="mainwindow.cpp" line="1014"/>
         <source>Program for troubleshooting and configuring network for antiX Linux</source>
-        <translation type="unfinished"/>
+        <translation>תכנית לפתרון תקלות ולהגדרת רשת עבור antiX Linux</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="1016"/>
         <source>Copyright (c) MEPIS LLC and MX Linux</source>
-        <translation type="unfinished"/>
+        <translation>זכויות היוצרים (c) שמורות ל־MEPIS LLC ול־MX Linux</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="1017"/>
         <source>%1 License</source>
-        <translation type="unfinished"/>
+        <translation>רישיון %1</translation>
     </message>
 </context>
 <context>
@@ -405,13 +405,13 @@
     <message>
         <location filename="about.cpp" line="32"/>
         <source>License</source>
-        <translation>רשיון</translation>
+        <translation>רישיון</translation>
     </message>
     <message>
         <location filename="about.cpp" line="33"/>
         <location filename="about.cpp" line="43"/>
         <source>Changelog</source>
-        <translation type="unfinished"/>
+        <translation>יומן שינויים</translation>
     </message>
     <message>
         <location filename="about.cpp" line="34"/>
@@ -421,101 +421,102 @@
     <message>
         <location filename="about.cpp" line="51"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"/>
+        <translation>&amp;סגירה</translation>
     </message>
     <message>
         <location filename="main.cpp" line="44"/>
         <source>You must run this program as root.</source>
-        <translation>אתה חייב להריץ את התוכנה הזו עם הרשאות root.</translation>
+        <translation>חובה להריץ את התכנית הזו כמשתמש על (root).</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="509"/>
         <source>Ndiswrapper is not installed</source>
-        <translation type="unfinished"/>
+        <translation>Ndiswrapper לא מותקן</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="521"/>
         <source>driver installed</source>
-        <translation type="unfinished"/>
+        <translation>מנהל ההתקן הותקן</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="529"/>
         <source> and in use by </source>
-        <translation type="unfinished"/>
+        <translation>ובשימוש של</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="536"/>
         <source>. Alternate driver: </source>
-        <translation type="unfinished"/>
+        <translation>. מנהל התקן חלופי: </translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="613"/>
         <source>Driver removed from blocklist</source>
-        <translation type="unfinished"/>
+        <translation>מנהל ההתקן הוסר מרשימת החסימה</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="614"/>
         <source>Driver removed from blocklist.</source>
-        <translation type="unfinished"/>
+        <translation>מנהל ההתקן הוסר מרשימת החסימה.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="620"/>
         <location filename="mainwindow.cpp" line="621"/>
         <source>Module blocked</source>
-        <translation type="unfinished"/>
+        <translation>המודול נחסם</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="786"/>
         <source>Installation successful</source>
-        <translation type="unfinished"/>
+        <translation>ההתקנה הצליחה</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="789"/>
         <source>Error detected, could not compile ndiswrapper driver.</source>
-        <translation type="unfinished"/>
+        <translation>זוהתה שגיאה, לא ניתן להדר את מנהל ההתקן עם ndiswrapper.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="792"/>
         <source>Error detected, could not install ndiswrapper.</source>
-        <translation type="unfinished"/>
+        <translation>זוהתה שגיאה, לא ניתן להתקין את ndiswrapper.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="804"/>
         <source>Error encountered while removing Ndiswrapper</source>
-        <translation type="unfinished"/>
+        <translation>אירעה שגיאה בעת הסרת Ndiswrapper</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="855"/>
         <source>Unblock Driver</source>
-        <translation type="unfinished"/>
+        <translation>שחרור חסימת מנהל התקן</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="858"/>
         <source>Block Driver</source>
-        <translation type="unfinished"/>
+        <translation>חסימת מנהל התקן</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="995"/>
         <source>Could not unlock devices.
 WiFi device(s) might already be unlocked.</source>
-        <translation type="unfinished"/>
+        <translation>לא ניתן לשחרר התקנים.
+התקני הרשת האלחוטית כנראה כבר משוחררים.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="997"/>
         <source>WiFi devices unlocked.</source>
-        <translation type="unfinished"/>
+        <translation>התקני הרשת האלחוטית שוחררו.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="1040"/>
         <location filename="mainwindow.cpp" line="1041"/>
         <source>Driver loaded successfully</source>
-        <translation type="unfinished"/>
+        <translation>מנהל ההתקן נטען</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="1056"/>
         <location filename="mainwindow.cpp" line="1057"/>
         <source>Driver unloaded successfully</source>
-        <translation type="unfinished"/>
+        <translation>מנהל ההתקן נפרק</translation>
     </message>
 </context>
 <context>
@@ -523,12 +524,12 @@ WiFi device(s) might already be unlocked.</source>
     <message>
         <location filename="mainwindow.cpp" line="638"/>
         <source>Could not load </source>
-        <translation type="unfinished"/>
+        <translation>לא ניתן לטעון</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="669"/>
         <source>Could not unload </source>
-        <translation type="unfinished"/>
+        <translation>לא ניתן לפרוק</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
